@@ -6,7 +6,7 @@ from typing import Tuple
 import ndebug
 
 from ..errors import UnknownCommitMessageStyleError
-from .parser_helpers import parse_text_block
+from .parser_helpers import parse_text_block, re_breaking
 
 debug = ndebug.create(__name__)
 
@@ -25,7 +25,8 @@ TYPES = {
 
 re_parser = re.compile(
     r'(?P<type>' + '|'.join(TYPES.keys()) + ')'
-    r'(?:\((?P<scope>[^\n]+)\))?: '
+    r'(?:\((?P<scope>[^\n]+)\))?'
+    r'(?P<break>!)?: '
     r'(?P<subject>[^\n]+)'
     r'(:?\n\n(?P<text>.+))?',
     re.DOTALL
@@ -55,8 +56,10 @@ def parse_commit_message(message: str) -> Tuple[int, str, str, Tuple[str, str, s
             'Unable to parse the given commit message: {}'.format(message)
         )
 
+    body, footer = parse_text_block(parsed.group('text'))
+
     level_bump = 0
-    if parsed.group('text') and 'BREAKING CHANGE' in parsed.group('text'):
+    if parsed.group('break') or re_breaking.match(body) or re_breaking.match(footer):
         level_bump = 3
 
     if parsed.group('type') in MINOR_TYPES:
@@ -65,7 +68,6 @@ def parse_commit_message(message: str) -> Tuple[int, str, str, Tuple[str, str, s
     if parsed.group('type') in PATCH_TYPES:
         level_bump = max([level_bump, 1])
 
-    body, footer = parse_text_block(parsed.group('text'))
     if debug.enabled:
         debug('parse_commit_message -> ({}, {}, {}, {})'.format(
             level_bump,
